@@ -8,6 +8,10 @@
 #' requests.
 #'
 #' @param ... Arguments passed to `expect_warning`
+#' @param ignore.case logical: if `FALSE`, the pattern matching is _case
+#' sensitive_ and if `TRUE`, case is ignored during matching. Default is `TRUE`;
+#' note that this is the opposite of `expect_warning` but is appropriate here
+#' because HTTP header names are case insensitive.
 #' @return `NULL`, according to `expect_warning`.
 #' @importFrom httr add_headers
 #' @importFrom testthat expect_warning
@@ -18,8 +22,7 @@
 #'         "Accept: image/png")
 #' })
 #' @export
-expect_header <- function (...) {
-    # TODO: default to ignore.case=TRUE
+expect_header <- function (..., ignore.case=TRUE) {
     tracer <- quote({
         heads <- req$headers
         for (h in names(heads)) {
@@ -27,6 +30,6 @@ expect_header <- function (...) {
         }
     })
     with_trace("request_prepare", exit=tracer, where=add_headers, expr={
-        expect_warning(...)
+        expect_warning(..., ignore.case=ignore.case)
     })
 }
