@@ -58,24 +58,42 @@ with_mock_api({
             content(GET("api/object1/")))
     })
 
-    test_that("redact=NULL to override default (and loaded packages)", {
+    test_that("set_redactor(NULL) to override default (and loaded packages)", {
         expect_true("testpkg" %in% names(sessionInfo()$otherPkgs))
         ## Great, but let's kill it when we're done
-        on.exit(detach(package:testpkg))
+        on.exit(detach("package:testpkg", unload=TRUE))
         newmocks2 <- tempfile()
-        expect_warning(
-            capture_while_mocking(simplify=FALSE, path=newmocks2, redact=NULL, {
+        with_redactor(NULL,
+            capture_while_mocking(simplify=FALSE, path=newmocks2, {
                 a <- POST("http://example.com/login",
                     body=list(username="password"), encode="json")
-            }),
-            "The 'redact' argument to start_capturing() is deprecated. Use 'set_redactor()' instead.", fixed=TRUE
+            })
         )
+        # The auth token, which would have been removed (see test-redact.R),
+        # is present in the file we wrote because we set NULL as redactor
         expect_true(any(grepl("token=12345",
             readLines(file.path(newmocks2, "example.com", "login-712027-POST.R")))))
-        with_mock_path(newmocks2, {
-            b <- POST("http://example.com/login",
-                body=list(username="password"), encode="json")
+    })
+
+    test_that("Loading a package with pkgload (devtools)", {
+        newmocks3 <- tempfile()
+        expect_false("testpkg" %in% names(sessionInfo()$otherPkgs))
+        on.exit({
+            pkgload::unload("testpkg")
+            unloadNamespace("pkgload")
         })
-        expect_equal(content(b), content(a))
+        expect_message(
+            capture_while_mocking(path=newmocks3, {
+                pkgload::load_all("testpkg")
+                expect_true("testpkg" %in% names(sessionInfo()$otherPkgs))
+                r <- GET("http://example.com/get")
+            }),
+            paste0("Using redact.R from ", dQuote("testpkg"))
+        )
+        with_mock_path(newmocks3, {
+            r2 <- GET("http://example.com/get")
+        })
+        ## The resulting mock content is what we injected into it from testpkg
+        expect_identical(content(r2), list(fake=TRUE))
     })
 })
